@@ -1,4 +1,4 @@
-/*	$OpenBSD: ar_io.c,v 1.18 1998/09/20 02:22:21 millert Exp $	*/
+/*	$OpenBSD: ar_io.c,v 1.17 1997/09/01 18:29:42 deraadt Exp $	*/
 /*	$NetBSD: ar_io.c,v 1.5 1996/03/26 23:54:13 mrg Exp $	*/
 
 /*-
@@ -42,7 +42,7 @@
 #if 0
 static char sccsid[] = "@(#)ar_io.c	8.2 (Berkeley) 4/18/94";
 #else
-static char rcsid[] = "$OpenBSD: ar_io.c,v 1.18 1998/09/20 02:22:21 millert Exp $";
+static char rcsid[] = "$OpenBSD: ar_io.c,v 1.17 1997/09/01 18:29:42 deraadt Exp $";
 #endif
 #endif /* not lint */
 
@@ -316,12 +316,18 @@ void
 ar_close()
 #endif
 {
+	FILE *outf;
 
 	if (arfd < 0) {
 		did_io = io_ok = flcnt = 0;
 		return;
 	}
 
+	if (act == LIST)
+		outf = stdout;
+	else
+		outf = stderr;
+
 	/*
 	 * Close archive file. This may take a LONG while on tapes (we may be
 	 * forced to wait for the rewind to complete) so tell the user what is
@@ -330,11 +336,11 @@ ar_close()
 	 */
 	if (vflag && (artyp == ISTAPE)) {
 		if (vfpart)
-			(void)putc('\n', listf);
-		(void)fprintf(listf,
+			(void)putc('\n', outf);
+		(void)fprintf(outf,
 			"%s: Waiting for tape drive close to complete...",
 			argv0);
-		(void)fflush(listf);
+		(void)fflush(outf);
 	}
 
 	/*
@@ -350,9 +356,9 @@ ar_close()
 	(void)close(arfd);
 
 	if (vflag && (artyp == ISTAPE)) {
-		(void)fputs("done.\n", listf);
+		(void)fputs("done.\n", outf);
 		vfpart = 0;
-		(void)fflush(listf);
+		(void)fflush(outf);
 	}
 	arfd = -1;
 
@@ -378,7 +384,7 @@ ar_close()
 	 * Print out a summary of I/O for this archive volume.
 	 */
 	if (vfpart) {
-		(void)putc('\n', listf);
+		(void)putc('\n', outf);
 		vfpart = 0;
 	}
 
@@ -389,27 +395,27 @@ ar_close()
 	 */
 	if (frmt == NULL) {
 #	ifdef NET2_STAT
-		(void)fprintf(listf, "%s: unknown format, %lu bytes skipped.\n",
+		(void)fprintf(outf, "%s: unknown format, %lu bytes skipped.\n",
 #	else
-		(void)fprintf(listf, "%s: unknown format, %qu bytes skipped.\n",
+		(void)fprintf(outf, "%s: unknown format, %qu bytes skipped.\n",
 #	endif
 		    argv0, rdcnt);
-		(void)fflush(listf);
+		(void)fflush(outf);
 		flcnt = 0;
 		return;
 	}
 
 	if (strcmp(NM_CPIO, argv0) == 0)
-		(void)fprintf(listf, "%qu blocks\n", (rdcnt ? rdcnt : wrcnt) / 5120);
+		(void)fprintf(outf, "%qu blocks\n", (rdcnt ? rdcnt : wrcnt) / 5120);
 	else if (strcmp(NM_TAR, argv0) != 0)
-		(void)fprintf(listf,
+		(void)fprintf(outf,
 #	ifdef NET2_STAT
 		    "%s: %s vol %d, %lu files, %lu bytes read, %lu bytes written.\n",
 #	else
 		    "%s: %s vol %d, %lu files, %qu bytes read, %qu bytes written.\n",
 #	endif
 		    argv0, frmt->name, arvol-1, flcnt, rdcnt, wrcnt);
-	(void)fflush(listf);
+	(void)fflush(outf);
 	flcnt = 0;
 }
 
