@@ -1,4 +1,4 @@
-/*	$OpenBSD: options.c,v 1.34 1998/09/20 02:22:22 millert Exp $	*/
+/*	$OpenBSD: options.c,v 1.30 1997/09/01 18:29:54 deraadt Exp $	*/
 /*	$NetBSD: options.c,v 1.6 1996/03/26 23:54:18 mrg Exp $	*/
 
 /*-
@@ -42,7 +42,7 @@
 #if 0
 static char sccsid[] = "@(#)options.c	8.2 (Berkeley) 4/18/94";
 #else
-static char rcsid[] = "$OpenBSD: options.c,v 1.34 1998/09/20 02:22:22 millert Exp $";
+static char rcsid[] = "$OpenBSD: options.c,v 1.30 1997/09/01 18:29:54 deraadt Exp $";
 #endif
 #endif /* not lint */
 
@@ -64,6 +64,8 @@ static char rcsid[] = "$OpenBSD: options.c,v 1.34 1998/09/20 02:22:22 millert Ex
 #include "tar.h"
 #include "extern.h"
 
+#include "fgetln.h"	/* added, David */
+
 /*
  * Routines which handle command line options
  */
@@ -523,7 +525,6 @@ pax_options(argc, argv)
 	 */
 	if (ISLIST(flg)) {
 		act = LIST;
-		listf = stdout;
 		bflg = flg & BDLIST;
 	} else if (ISEXTRACT(flg)) {
 		act = EXTRACT;
@@ -673,10 +674,13 @@ tar_options(argc, argv)
 			break;
 		case 'p':
 			/*
-			 * preserve uid/gid and file mode, regardless of umask
+			 * preserve user id, group id, file
+			 * mode, access/modification times
 			 */
-			pmode = 1;
 			pids = 1;
+			pmode = 1;
+			patime = 1;
+			pmtime = 1;
 			break;
 		case 'r':
 		case 'u':
@@ -714,11 +718,9 @@ tar_options(argc, argv)
 			break;
 		case 'x':
 			/*
-			 * extract an archive, preserving mode,
-			 * and mtime if possible.
+			 * write an archive
 			 */
 			act = EXTRACT;
-			pmtime = 1;
 			break;
 		case 'z':
 			/*
@@ -792,12 +794,6 @@ tar_options(argc, argv)
 	argc -= optind;
 	argv += optind;
 
-	/* Traditional tar behaviour (pax uses stderr unless in list mode) */
-	if (fstdin == 1 && act == ARCHIVE)
-		listf = stderr;
-	else
-		listf = stdout;
-
 	/* Traditional tar behaviour (pax wants to read filelist from stdin) */
 	if ((act == ARCHIVE || act == APPND) && argc == 0)
 		exit(0);
@@ -1018,7 +1014,6 @@ cpio_options(argc, argv)
 				 * list contents of archive
 				 */
 				act = LIST;
-				listf = stdout;
 				break;
 			case 'u':
 				/*
@@ -1164,7 +1159,7 @@ cpio_options(argc, argv)
 			maxflt = 0;
 			while ((str = fgetln(stdin, &len)) != NULL) {
 				str[len - 1] = '\0';
-				ftree_add(strdup(str), NULL);
+				ftree_add(strdup(str), 0);
 			}
 			break;
 		default:
